```
Usage: vcd network [OPTIONS] COMMAND [ARGS]...

  Work with networks in vCloud Director.

      Examples
          vcd network list
              List all org vdc networks available in a org.
      

Options:
  -h, --help  Show this message and exit.

Commands:
  direct    work with directly connected org vdc networks
  external  work with external networks
  isolated  work with isolated org vdc networks
  list      list all org VDC networks in a org
  routed    work with routed org vdc networks

```
